from socket_utils import *
import sys

########################################################################################
# SYNOPSYS
# get_file_thread
#     Get file from a file server
#     Do all work in a dedicated thread !
#     This means that we can get many files in parallel !
#
# Arguments
#     file_server
#         File server address. Should have the form: "address:port"
#         Like:  shark.braude.ac.il:12345  ,  192.168.3.17:12348
#     remote_file
#         Name of file we want to get from the file server
#     local_file
#         Name of of the target file in the local client host
#     
# Examples
#     get_file_thread( "shark.braude.ac.il:12345", "c:/books/oliver.txt", "c:/books/oliver_copy.txt")
#     get_file_thread( "192.168.3.17:12348", "c:/books/oliver.txt", "c:/books/oliver_copy.txt")
#     These two calls will return immediately, while the file transfer action is done in the background
########################################################################################

def get_file_thread(file_server, remote_file, local_file):
    sock = socket.socket( socket.AF_INET, socket.SOCK_STREAM )
    host, port = file_server.split(':')
    server = (host, int(port))
    sock.connect(server)
    sock.sendall(remote_file + '\n')
    status_line = recv_delimited_message(sock)     # status line (like: "404 File not found")
    print status_line                              # print status line for client 
    if not status_line[0] == '2':                  # success status is: '2xx' (200, 201, ...)
        sock.close()
        return None
    
    file_size = int(recv_delimited_message(sock))  # expected file size, must be converted to integer!
    sock.sendall('OK')                             # Inform the server that file size arrived
    thread = RecvFileThread(sock, file_size, local_file) # Start a thread for receiving the file
    thread.start()
    return thread                                  # Return thread object to the caller
                                                   # Thread continues to work in the background

############################################################
# The following code will work only if file is executed
# from the command line!
# But if you import this file as a module, the next code
# will not be seen
############################################################
if __name__ == "__main__":
    file_server = sys.argv[1]
    remote_file = sys.argv[2]
    local_file  = sys.argv[3]
    if os.path.isdir(local_file):
        head,tail = os.path.split(remote_file)
        local_file = local_file + os.sep + tail
    get_file_thread(file_server, remote_file, local_file)
    #print "\n=== Main Thread Exiting ==="

